@@ -517,7 +517,7 @@ preparePlot<-function(fileName="Rplot", ...)
     else if (tolower(fileType[2])=="ps") 
         postscript(file = fileName, paper="default", horizontal=FALSE, encoding="ISOLatin1.enc",...)
     else if (tolower(fileType[2])=="emf" && .Platform$OS.type == "windows") 
-        win.metafile(file = fileName,...)
+        win.metafile(filename = fileName,...)
     else if (tolower(fileType[2])=="jpg")
         jpeg(filename = fileName, ...)
     else if (tolower(fileType[2])=="tif")
